==> nw-style-guide-15.1.0.tgz: package/charts/bar/bar.directive.js <==
import { Directive, Input } from '@angular/core';
import { select } from 'd3-selection';
import { scaleTime, scaleLinear } from 'd3-scale';
import { ChartUtils } from '../chart.utils';
import * as i0 from "@angular/core";
import * as i1 from "../chart.component";
import * as i2 from "../chart.utils";
export class BarDirective {
    constructor(_elRef, _chart, _chartUtils) {
        this._elRef = _elRef;
        this._chart = _chart;
        this._chartUtils = _chartUtils;
        this.animDuration = ChartUtils.ANIMATION_DURATION;
        this.easing = ChartUtils.ANIMATION_EASING;
        this.barWidth = 20;
        this.xScale = scaleTime();
        this.yScale = scaleLinear();
    }
    ngOnInit() {
        this.rect = select(this._elRef.nativeElement);
        this.setDomains();
        this.draw();
        this._subscribeToChartResize();
    }
    ngOnChanges(changes) {
        const isDomainChange = (changes.xDomain || changes.yDomain) && ChartUtils.haveDomainsChanged(changes.xDomain, changes.yDomain);
        const isDataChange = changes.value && !changes.value.firstChange && !ChartUtils.areDatasetsEqual([changes.value.previousValue], [changes.value.currentValue]);
        const barWidthChange = changes.barWidth && !changes.barWidth.firstChange && (changes.barWidth.previousValue !== changes.barWidth.currentValue);
        if (isDomainChange || isDataChange || barWidthChange) {
            this.setDomains();
            this.draw(this.animDuration);
        }
    }
    setDomains() {
        this.xScale.domain(this.xDomain).range([0, this._chart.width]);
        this.yScale.domain(this.yDomain).range([this._chart.height, 0]);
    }
    draw(animDuration = 0) {
        this.rect
            .transition()
            .duration(animDuration)
            .ease(this.easing)
            .attr('x', this.xScale(this.value[0]) - (this.barWidth / 2))
            .attr('y', this.yScale(this.value[1]))
            .attr("width", this.barWidth)
            .attr("height", this._chart.height - this.yScale(this.value[1]));
    }
    _subscribeToChartResize() {
        this._chartResizeSub = this._chartUtils.chartResize$
            .subscribe(_ => {
            this.setDomains();
            this.draw();
        });
    }
    ngOnDestroy() {
        this._chartResizeSub.unsubscribe();
    }
}
BarDirective.ɵfac = function BarDirective_Factory(t) { return new (t || BarDirective)(i0.ɵɵdirectiveInject(i0.ElementRef), i0.ɵɵdirectiveInject(i1.ChartComponent), i0.ɵɵdirectiveInject(i2.ChartUtils)); };
BarDirective.ɵdir = /*@__PURE__*/ i0.ɵɵdefineDirective({ type: BarDirective, selectors: [["rect", "nw-bar", ""]], inputs: { value: [i0.ɵɵInputFlags.None, "nw-bar", "value"], xDomain: "xDomain", yDomain: "yDomain", animDuration: "animDuration", easing: "easing", barWidth: "barWidth", xScale: "xScale" }, features: [i0.ɵɵNgOnChangesFeature] });
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(BarDirective, [{
        type: Directive,
        args: [{
                // eslint-disable-next-line @angular-eslint/directive-selector
                selector: 'rect[nw-bar]'
            }]
    }], () => [{ type: i0.ElementRef }, { type: i1.ChartComponent }, { type: i2.ChartUtils }], { value: [{
            type: Input,
            args: ['nw-bar']
        }], xDomain: [{
            type: Input
        }], yDomain: [{
            type: Input
        }], animDuration: [{
            type: Input
        }], easing: [{
            type: Input
        }], barWidth: [{
            type: Input
        }], xScale: [{
            type: Input
        }] }); })();

==> nw-style-guide-16.1.0.tgz: package/charts/bar/bar.directive.js <==
import { Directive, Input } from '@angular/core';
import { select } from 'd3-selection';
import { scaleTime, scaleLinear } from 'd3-scale';
import { ChartUtils } from '../chart.utils';
import * as i0 from "@angular/core";
import * as i1 from "../chart.component";
import * as i2 from "../chart.utils";
export class BarDirective {
    constructor(_elRef, _chart, _chartUtils) {
        this._elRef = _elRef;
        this._chart = _chart;
        this._chartUtils = _chartUtils;
        this.animDuration = ChartUtils.ANIMATION_DURATION;
        this.easing = ChartUtils.ANIMATION_EASING;
        this.barWidth = 20;
        this.xScale = scaleTime();
        this.yScale = scaleLinear();
    }
    ngOnInit() {
        this.rect = select(this._elRef.nativeElement);
        this.setDomains();
        this.draw();
        this._subscribeToChartResize();
    }
    ngOnChanges(changes) {
        const isDomainChange = (changes.xDomain || changes.yDomain) && ChartUtils.haveDomainsChanged(changes.xDomain, changes.yDomain);
        const isDataChange = changes.value && !changes.value.firstChange && !ChartUtils.areDatasetsEqual([changes.value.previousValue], [changes.value.currentValue]);
        const barWidthChange = changes.barWidth && !changes.barWidth.firstChange && (changes.barWidth.previousValue !== changes.barWidth.currentValue);
        if (isDomainChange || isDataChange || barWidthChange) {
            this.setDomains();
            this.draw(this.animDuration);
        }
    }
    setDomains() {
        this.xScale.domain(this.xDomain).range([0, this._chart.width]);
        this.yScale.domain(this.yDomain).range([this._chart.height, 0]);
    }
    draw(animDuration = 0) {
        const x = this.value[0];
        const y2 = this.value[1];
        const y1 = this.value[2];
        const height = y1 ? y2 - y1 : y2;
        this.rect
            .transition()
            .duration(animDuration)
            .ease(this.easing)
            .attr('x', this.xScale(x) - (this.barWidth / 2))
            .attr('y', this.yScale(y2))
            .attr("width", this.barWidth)
            .attr("height", this._chart.height - this.yScale(height));
    }
    _subscribeToChartResize() {
        this._chartResizeSub = this._chartUtils.chartResize$
            .subscribe(_ => {
            this.setDomains();
            this.draw();
        });
    }
    ngOnDestroy() {
        this._chartResizeSub.unsubscribe();
    }
}
BarDirective.ɵfac = function BarDirective_Factory(t) { return new (t || BarDirective)(i0.ɵɵdirectiveInject(i0.ElementRef), i0.ɵɵdirectiveInject(i1.ChartComponent), i0.ɵɵdirectiveInject(i2.ChartUtils)); };
BarDirective.ɵdir = /*@__PURE__*/ i0.ɵɵdefineDirective({ type: BarDirective, selectors: [["rect", "nw-bar", ""]], inputs: { value: [i0.ɵɵInputFlags.None, "nw-bar", "value"], xDomain: "xDomain", yDomain: "yDomain", animDuration: "animDuration", easing: "easing", barWidth: "barWidth", xScale: "xScale" }, features: [i0.ɵɵNgOnChangesFeature] });
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(BarDirective, [{
        type: Directive,
        args: [{
                // eslint-disable-next-line @angular-eslint/directive-selector
                selector: 'rect[nw-bar]'
            }]
    }], () => [{ type: i0.ElementRef }, { type: i1.ChartComponent }, { type: i2.ChartUtils }], { value: [{
            type: Input,
            args: ['nw-bar']
        }], xDomain: [{
            type: Input
        }], yDomain: [{
            type: Input
        }], animDuration: [{
            type: Input
        }], easing: [{
            type: Input
        }], barWidth: [{
            type: Input
        }], xScale: [{
            type: Input
        }] }); })();
